
// ===============================================
// Scanner's Java - Identifier for animation files
// ===============================================

package redhorizon.filetypes;

import java.nio.ByteBuffer;

/**
 * Interface and identifier for the animation filetypes in this package (eg:
 * SHP, WSA, etc...).  Animations are much like a video, except that they don't
 * include any soundtrack (a sound may be played during an animation, but this
 * is beyond the scope of this interface).
 *
 * @author Emanuel Rabina
 */
public interface AnimationFile extends ImageColourFormat {

	/**
	 * Returns the adjustment factor for the height of the animation.  Used
	 * mainly for older file formats of C&C where the display was either 320x200
	 * or 640x400 (a 8:5 or 1.6 pixel ratio).
	 * 
	 * @return A value to multiply the height of the animation by to get the
	 * 		   right look and feel.  Returns 1 if no adjustment is necessary.
	 */
	public float adjustmentFactor();

	/**
	 * Returns the speed at which this animation should be run, in
	 * frames/second.
	 * 
	 * @return Animation speed, as the frames component of frames/second.
	 */
	public float frameRate();

	/**
	 * Returns the image data for all of the images in this file.
	 * 
	 * @return <code>ByteBuffer</code>[] containing the data for all of the
	 * 		   images.
	 */
	public ByteBuffer[] getImages();

	/**
	 * Returns the height of the image.
	 * 
	 * @return Height of the image.
	 */
	public int height();

	/**
	 * Returns the number of images used to constitute this animation.
	 *
	 * @return Number of frames in the animation.
	 */
	public int numImages();

	/**
	 * Returns the width of the image.
	 * 
	 * @return Width of the image.
	 */
	public int width();
}
