
// ==============================================
// Scanner's Java - Interface for file containers
// ==============================================

package redhorizon.filetypes;

import redhorizon.utilities.FilePointer;

/**
 * Interface for file formats which are holders of other files (eg: MIX, ZIP,
 * etc...).
 * 
 * @author Emanuel Rabina
 */
public interface ArchiveFile {

	/**
	 * Returns a <code>FilePointer</code> starting at the position of the given
	 * item inside the body of the file.<br>
	 * <br>
	 * The name parameter is the proper filename of the item had it existed on
	 * the file system, eg: 2TNK.shp.
	 * 
	 * @param itemname The name of the item we're after.
	 * @return A <code>FilePointer</code>, already offset to the start of the
	 * 		   item and bound to the size of the item.
	 */
	public FilePointer getItem(String itemname);

	/**
	 * Queries the container as to whether or not an item by the given name
	 * exists within the container.
	 * 
	 * @param itemname Name of the item being searched for.
	 * @return <code>true</code> if the item resides within the file,
	 * 		   <code>false</code> otherwise.
	 */
	public boolean hasItem(String itemname);
}
