
// ===================================================
// Scanner's AspectJ - Marks when a file has been read
// ===================================================

package redhorizon.filetypes;

/**
 * Marks when a file has been read, so that the program can know if a file
 * should be read-from-file or not.
 * 
 * @author Emanuel Rabina
 */
public aspect FileRead {

	// Flag on the FileImplementation to mark read state
	private boolean FileImplementation.read;

	/**
	 * Allows a program to check if this file has been read.
	 * 
	 * @return <code>true</code> if the implementation has already gathered it's
	 * 		   data from file, <code>false</code> otherwise.
	 */
	public boolean FileImplementation.hasBeenRead() {

		return read;
	}

	/**
	 * Turns-on the 'read' flag after the read method has been run.
	 * 
	 * @param fileimpl The implementation just run.
	 */
	after(FileImplementation fileimpl) returning:
		execution(public void FileImplementation.readFromFile()) && this(fileimpl) {

		fileimpl.read = true;
	}
}
