
// ========================================
// Scanner's Java - Common image file parts
// ========================================

package redhorizon.filetypes;

/**
 * Interface containing parts common to all of the image file types in this
 * package.  Made to reduce code duplication.
 * 
 * @author Emanuel Rabina
 */
interface ImageColourFormat {

	public static final int FORMAT_RGB  = 3;
	public static final int FORMAT_RGBA = 4;

	/**
	 * Returns the number of bytes used to represent the colour data of a single
	 * pixel.  For images with no transparency, this should be
	 * {@link #FORMAT_RGB} (3).  For images with transparency, this should be
	 * {@link #FORMAT_RGBA} (4).<br>
	 * <br>
	 * If the object implements the {@link Paletted} interface, then the return
	 * value of this method is more of an expectation of the colour-depth,
	 * rather than a given.
	 * 
	 * @return 3 or 4 for RGB or RGBA images respectively.
	 */
	public int format();
}
