
// ==================================================
// Scanner's Java - Identifier for image file formats
// ==================================================

package redhorizon.filetypes;

import java.nio.ByteBuffer;

/**
 * Interface and identifier of the filetypes in this package that are image
 * formats (eg: PCX, BMP, SHP, etc...).  Contains signatures for functions
 * common to image formats.
 * 
 * @author Emanuel Rabina
 */
public interface ImageFile extends ImageColourFormat {

	/**
	 * Returns the image data from this file in a form useable by the game.
	 * 
	 * @return <code>ByteBuffer</code> containing the bytes in RGB(A) order for
	 * 		   the image.
	 */
	public ByteBuffer getImage();

	/**
	 * Returns the height of the image.
	 * 
	 * @return Height of the image.
	 */
	public int height();

	/**
	 * Returns the width of the image.
	 * 
	 * @return Width of the image.
	 */
	public int width();
}
