
// ================================================
// Scanner's Java - Interface for multi-image files
// ================================================

package redhorizon.filetypes;

import java.nio.ByteBuffer;

/**
 * Interface for files which contain multiple images.  These form the basis for
 * animation filetypes, as well as files which just contain several images to
 * represent a whole (eg: map tiles).
 * 
 * @author Emanuel Rabina
 */
public interface ImagesFile extends ImageColourFormat {

	/**
	 * Returns the image data for all of the images in this file.
	 * 
	 * @return <code>ByteBuffer</code>[] containing the data for all of the
	 * 		   images.
	 */
	public ByteBuffer[] getImages();

	/**
	 * Returns the height of the specified image.
	 * 
	 * @param imagenum The number of the image in the file.
	 * @return Height of the image.
	 */
	public int height(int imagenum);

	/**
	 * Returns the number of images used to constitute this animation.
	 *
	 * @return Number of frames in the animation.
	 */
	public int numImages();

	/**
	 * Returns the width of the specified image.
	 * 
	 * @param imagenum The number of the image in the file.
	 * @return Width of the image.
	 */
	public int width(int imagenum);
}
