
// =========================================
// Scanner's Java - Paletted image interface
// =========================================

package redhorizon.filetypes;

import java.nio.ByteBuffer;

/**
 * Interface which identifies the file format as using indexed data to represent
 * the image information returned by the implementing class.  Thus requiring a
 * matching external palette to obtain the whole image (which should be applied
 * using the {@link #applyPalette(PaletteFile)} method).<br>
 * <br>
 * A file format which contains an internal palette is not considered
 * <code>Paletted</code>.
 * 
 * @author Emanuel Rabina
 */
public interface Paletted {

	/**
	 * Routine for applying an external palette to this paletted image/s,
	 * completing the image/s as a whole.  This returned data is new and doesn't
	 * alter the original indexed data which the file contains.  This way
	 * subsequent calls to this method can be made, each returning a different
	 * palette application.
	 * 
	 * @param palette External palette to apply to the indexed image/s.
	 * @return Full-colour image/s of the original indexed data with the palette
	 * 		   applied.
	 */
	public ByteBuffer[] applyPalette(PaletteFile palette);
}
