
// ==========================================
// Scanner's Java - Settings format interface
// ==========================================

package redhorizon.filetypes;

import java.util.Map;

/**
 * Interface for settings file formats (eg: INI).  These are files commonly used
 * for configuration purposes, with a section header of the form
 * <code>[Header]</code>, and parameters following afterwards as
 * <code>Name = Value</code>.  Comment lines, denoted by the semi-colon
 * <code>;</code> may also be used
 * 
 * @author Emanuel Rabina
 */
public interface SettingsFile {

	/**
	 * Returns a map of parameter values tied to the given section name.
	 * 
	 * @param section Name of the section to take the values from.
	 * @return <code>Map</code> containing key/value pairs for the parameter
	 * 		   name/value respectively.
	 */
	public Map<String,String> getSection(String section);

	/**
	 * Returns a map of all sections.  Used for parsing entire settings files.
	 * 
	 * @return <code>Map</code> of all of the sections in this settings file.
	 */
	public Map<String,Map<String,String>> getSections();

	/**
	 * Returns whether or not the settings contain the requested section.
	 * 
	 * @param section Name of the section to query.
	 * @return <code>true</code> if the section exists, <code>false</code>
	 * 		   otherwise.
	 */
	public boolean hasSection(String section);

	/**
	 * Returns the value of the given parameter in the given section.
	 * 
	 * @param section	The section of the settings file in which the parameter
	 * 					resides.
	 * @param parameter The name of the parameter within that section.
	 * @return The value of the setting, or <code>null</code> if that parameter
	 * 		   doesn't exist.
	 */
	public String getValue(String section, String parameter);
}
