
// ==========================================
// Scanner's Java - Sound file interface type
// ==========================================

package redhorizon.filetypes;

import java.nio.ByteBuffer;

/**
 * Interface for filetypes for sound data (eg: AUD, WAV, etc...).  Defines the
 * signatures of methods required by any sound files.
 * 
 * @author Emanuel Rabina
 */
public interface SoundFile {

	/**
	 * Returns the bitrate of the sound sample is.
	 * 
	 * @return 8 or 16 for 8 or 16 bits/sample respectively.
	 */
	public int bitrate();

	/**
	 * Returns the number of sound channels used by the sound.
	 * 
	 * @return 1 or 2 for mono or stereo sound respectively.
	 */
	public int channels();

	/**
	 * Returns the frequency (number of samples/second) of the sound.
	 * 
	 * @return The frequency of the sound.
	 */
	public int frequency();

	/**
	 * Returns the sound data in a form useable by the game (PCM sine wave?).
	 * 
	 * @return <code>ByteBuffer</code> containing the sound data.
	 */
	public ByteBuffer getSound();
}
