
// =========================================================
// Scanner's Java - Representation of a paramater/value pair
// =========================================================

package redhorizon.filetypes.ini;

/**
 * Representation of a parameter found in .ini files.  Usually of the format:
 * <code>ParamName = ParamValue ;comment</code> this class provides easier
 * parsing and access of a .ini parameter.
 * 
 * @author Emanuel Rabina
 */
public class IniParameter {

	final String name;
	final String value;
	final String comment;

	/**
	 * Constructor, takes a line from a file.
	 * 
	 * @param line A line from a file containing a parameter.
	 */
	IniParameter(String line) {

		name = (line.substring(0, line.indexOf('='))).trim();

		if (line.contains(";")) {
			value = (line.substring(line.indexOf('=') + 1, line.indexOf(';'))).trim();
			comment = line.contains("\t") ? line.substring(line.indexOf('\t') + 1) : null;
		}
		else {
			value = (line.substring(line.indexOf('=') + 1)).trim();
			comment = null;
		}
	}

	/**
	 * Returns a <code>String</code> representation of this INI parameter.
	 * 
	 * @return <code>String</code> representation of this parameter.
	 */
	public String toString() {

		return name + " = " + value + ((comment != null) ? "\t" + comment : "");
	}
}
