
// ==============================================================
// Scanner's Java - Representation of a section of FileParameters
// ==============================================================

package redhorizon.filetypes.ini;

/**
 * Representation of a section of parameters found in .ini files.  The beginning
 * of sections are denoted by a header, usually of the format:
 * <code>[SectionHeader]</code>.  This class provides easier parsing and access
 * of a .ini section.
 * 
 * @author Emanuel Rabina
 */
public class IniSection {

	final String header;

	/**
	 * Constructor, takes a line from a file.
	 * 
	 * @param header A line from a file containing a section header.
	 */
	IniSection(String header) {

		this.header = header.substring(header.indexOf('[') + 1, header.indexOf(']'));
	}

	/**
	 * Returns a <code>String</code> representation of this INI section.
	 * 
	 * @return <code>String</code> representation of this section.
	 */
	public String toString() {

		return "[" + header + "]";
	}
}
