
// ===============================================
// Scanner's Java - Representation of a MIX header
// ===============================================

package redhorizon.filetypes.mix;

import redhorizon.utilities.FilePointer;

import java.nio.ByteBuffer;
import java.util.Arrays;

/**
 * Representation of a Red Alert MIX file header, which contains information
 * about the mix file and it's contents.
 * 
 * @author Emanuel Rabina
 */
public class MixHeader {

	final short numfiles;
	final int bodylength;
	final MixRecord[] index;

	private int entry;

	/**
	 * Constructor, takes a <code>ByteBuffer</code> and assigns the bytes to the
	 * variables of the header.
	 * 
	 * @param bytes A wrapped array of bytes which consists of the header.
	 */
	MixHeader(ByteBuffer bytes) {

		numfiles   = bytes.getShort();
		bodylength = bytes.getInt();
		index      = new MixRecord[numfiles];
	}

	/**
	 * Constructor, takes a <code>FilePointer</code> and assigns the header
	 * information from it.
	 * 
	 * @param file <code>FilePointer</code> to the header portion of a MIX file.
	 */
	MixHeader(FilePointer file) {

		numfiles   = file.readShort();
		bodylength = file.readInt();
		index      = new MixRecord[numfiles];
	}

	/**
	 * Adds a new entry to the index.
	 * 
	 * @param newrecord The new <code>MixRecord</code> to add.
	 */
	void addRecord(MixRecord newrecord) {

		index[entry++] = newrecord;
		if (entry == numfiles) {
			Arrays.sort(index);
		}
	}
}
