
// ====================================================
// Scanner's Java - Representation of a MIX index entry
// ====================================================

package redhorizon.filetypes.mix;

import redhorizon.utilities.FilePointer;

import java.nio.ByteBuffer;

/**
 * Representation of a Red Alert MIX file index record, found in the header of
 * MIX files to indicate where content can be located within the body.
 * 
 * @author Emanuel Rabina
 */
public class MixRecord implements Comparable<MixRecord> {

	final int id;
	final int offset;
	final int length;

	/**
	 * Constructor, assigns the ID, offset, and length of this entry from the
	 * given <code>ByteBuffer</code> object.
	 * 
	 * @param bytes A wrapped array of bytes which contains the entry.
	 */
	MixRecord(ByteBuffer bytes) {

		id     = bytes.getInt();
		offset = bytes.getInt();
		length = bytes.getInt();
	}

	/**
	 * Constructor, assigns the record values from the <code>FilePointer</code>.
	 * 
	 * @param file <code>FilePointer</code> to a record entry in the mix file.
	 */
	MixRecord(FilePointer file) {

		id     = file.readInt();
		offset = file.readInt();
		length = file.readInt();
	}

	/**
	 * Compares this record to the other, returns negative, zero, or positive if
	 * this record's ID is less than, equal to, or greater than the one being
	 * compared to.
	 * 
	 * @param other The other <code>MixRecord</code> to compare with.
	 * @return -1, 0, 1 :: less-than, equal to, greater than.
	 */
	public int compareTo(MixRecord other) {

		int thisid = this.id;
		int otherid = other.id;

		if (thisid < otherid) {
			return -1;
		}
		else if (thisid > otherid) {
			return 1;
		}
		else {
			return 0;
		}
	}
}
