
// ================================
// Scanner's Java - PCX file header
// ================================

package redhorizon.filetypes.pcx;

import redhorizon.utilities.FilePointer;

/**
 * Representation of the PCX file's header, which contains information about the
 * data in the file.
 * 
 * @author Emanuel Rabina
 */
public class PcxHeader {

	final byte manufacturer;
	final byte version;
	final byte encoding;
	final byte bitsperpixel;
	final short xmin;
	final short ymin;
	final short xmax;
	final short ymax;
	final short hdpi;
	final short vdpi;
	final byte[] palette;
	final byte reserved;
	final byte planes;
	final short bytesperline;
	final short paletteinfo;
	final byte[] filler;

	/**
	 * Constructor, assigns the variables of the header with the data at the
	 * <code>FilePointer</code>
	 * 
	 * @param file <code>FilePointer</code> pointing at the header section of a
	 * 			   PCX file.
	 */
	PcxHeader(FilePointer file) {

		manufacturer = file.readByte();
		version      = file.readByte();
		encoding     = file.readByte();
		bitsperpixel = file.readByte();
		xmin         = file.readShort();
		ymin         = file.readShort();
		xmax         = file.readShort();
		ymax         = file.readShort();
		hdpi         = file.readShort();
		vdpi         = file.readShort();
		palette      = file.readBytes(48).array();
		reserved     = file.readByte();
		planes       = file.readByte();
		bytesperline = file.readShort();
		paletteinfo  = file.readShort();
		filler       = file.readBytes(58).array();
	}
}
