
// ============================================
// Scanner's Java - Internal PNG palette colour
// ============================================

package redhorizon.filetypes.png;

import redhorizon.filetypes.pal.PalColour;

/**
 * Representation of a colour in a PNG file's internal palette.  Draws a lot of
 * similarties to the general palette colour representation.
 * 
 * @author Emanuel Rabina
 * @see PalColour
 */
public class PngColour extends PalColour {

	private byte alpha;
	private boolean hasalpha;

	/**
	 * Constructor, creates the RGB colour with the given RGB components.
	 * 
	 * @param red	Red component.
	 * @param green Green component.
	 * @param blue	Blue component.
	 */
	PngColour(byte red, byte green, byte blue) {

		super(red, green, blue);
	}

	/**
	 * Constructor, creates an RGBA colour with the given components.
	 * 
	 * @param red	Red component.
	 * @param green Green component.
	 * @param blue	Blue component.
	 * @param alpha Alpha component.
	 */
	PngColour(byte red, byte green, byte blue, byte alpha) {

		super(red, green, blue);
		this.alpha = alpha;
		hasalpha = true;
	}

	/**
	 * Returns the RGBA components as an array.
	 * 
	 * @return <code>byte[]</code> with the 0th, 1st, 2nd and 3rd bytes
	 * 		   representing the red, green, blue and alpha parts respectively.
	 */
	public byte[] toArray() {

		return hasalpha ?
				new byte[]{ getRed(), getGreen(), getBlue(), alpha }:
				new byte[]{ getRed(), getGreen(), getBlue() };
	}
}
