
// ===============================================
// Scanner's Java - Representation of a SHP header
// ===============================================

package redhorizon.filetypes.shp;

import redhorizon.utilities.FilePointer;

/**
 * Representation of a SHP file's header format.  This is mainly some basic
 * image data on the SHP file.
 * 
 * @author Emanuel Rabina
 */
public class ShpFileHeader {

	final short numimages;
	final short unknown1;
	final short unknown2;
	final short width;
	final short height;
	final int unknown3;
	final ShpImageOffset[] offsets;

	private int entry;

	/**
	 * Constructor, obtains image parameters from the <code>FilePointer</code>.
	 * 
	 * @param file <code>FilePointer</code> at the header of the SHP file.
	 */
	ShpFileHeader(FilePointer file) {

		numimages = file.readShort();
		unknown1  = file.readShort();
		unknown2  = file.readShort();
		width     = file.readShort();
		height    = file.readShort();
		unknown3  = file.readInt();
		offsets   = new ShpImageOffset[numimages + 2];
	}

	/**
	 * Adds a <code>ShpOffset</code> to this header at the first available
	 * position in the list of offsets.
	 * 
	 * @param newoffset The <code>ShpOffset</code> to add.
	 */
	void addOffSet(ShpImageOffset newoffset) {

		offsets[entry++] = newoffset;
	}
}
