
// =======================================
// Scanner's Java - Dune 2 SHP file header
// =======================================

package redhorizon.filetypes.shp;

import redhorizon.utilities.FilePointer;

/**
 * Representation of a Dune 2 SHP file header.
 * 
 * @author Emanuel Rabina
 */
public class ShpFileHeaderDune2 {

	final short numimages;
	final int[] imageoffsets;
	final int endoffile;

	private int offsettype = -1;

	/**
	 * Constructor, fills-out the header from the <code>FilePointer</code>.
	 * 
	 * @param file <code>FilePointer</code> to the Dune 2 SHP file.
	 */
	ShpFileHeaderDune2(FilePointer file) {

		numimages = file.readShort();
		imageoffsets = new int[numimages];

		// Discover the offset type
		offsettype = file.readByte(4) != 0 ? 2 : 4;

		for (int i = 0; i < numimages; i++) {
			if (offsettype == 2) {
				imageoffsets[i] = file.readShort() & 0xff;
			}
			else {
				imageoffsets[i] = file.readInt();
			}
		}

		endoffile = file.readInt();
	}

	/**
	 * Constructor, uses the given parameters to complete this header.
	 * 
	 * @param numimages Number of images in the file.
	 * @param imageoffsets Array of locations in the file for where to find the
	 * 					   image header + data.
	 * @param endoffile	   The position of the end of the file.
	 */
	ShpFileHeaderDune2(short numimages, int[] imageoffsets, int endoffile) {

		this.numimages    = numimages;
		this.imageoffsets = imageoffsets;
		this.endoffile    = endoffile;
	}

	/**
	 * Return the offset type.  The offset type is the size (in bytes) of the
	 * offsets that point to the locations of the image headers + data in the
	 * file.
	 * 
	 * @return The offset type for this Dune 2 SHP file.
	 */
	int getOffsetType() {

		if (offsettype == -1) {
			offsettype = (imageoffsets[numimages - 1] & 0x0100) == 0 ? 2 : 4;
		}
		return offsettype;
	}
}
