
// ========================================
// Scanner's Java - Dune 2 SHP image header
// ========================================

package redhorizon.filetypes.shp;

import redhorizon.utilities.FilePointer;

/**
 * Representation of the Dune 2 SHP image header (different from the file
 * header), which contains data on the image it references.
 * 
 * @author Emanuel Rabina
 */
public class ShpImageHeaderDune2 {

	final short compression;
	final byte  slices;
	final short width;
	final byte  height;
	final short filesize;
	final short datasize;

	/**
	 * Constructor, fills-out the header from the <code>FilePointer</code>.
	 * 
	 * @param file <code>FilePointer</code> to the Dune 2 SHP image header.
	 */
	ShpImageHeaderDune2(FilePointer file) {

		this(file.readShort(), file.readByte(), file.readShort(), file.readByte(),
				file.readShort(), file.readShort());
	}

	/**
	 * Constructor, uses the given parameters to complete this header.
	 * 
	 * @param compression Flags to indicate what compression has been used.
	 * @param slices	  Number of rows Format2 compression was used on.  This
	 * 					  is usually the height of the image.
	 * @param width		  Image width.
	 * @param height	  Image height.
	 * @param filesize	  Size of the data (image header + image data) on file.
	 * @param datasize	  Size of the data when in Format2 form.
	 */
	ShpImageHeaderDune2(short compression, byte slices, short width, byte height,
			short filesize, short datasize) {

		this.compression = compression;
		this.slices      = slices;
		this.width       = width;
		this.height      = height;
		this.filesize    = filesize;
		this.datasize    = datasize;
	}
}
