
// ====================================================================
// Scanner's java - Representation of the offsets section of a SHP file
// ====================================================================

package redhorizon.filetypes.shp;

import redhorizon.utilities.FilePointer;

/**
 * Representation of an offset record found in SHP files.  It turns out that not
 * all SHP files are just straight images in their own right, but some form of
 * 'difference' data (think video difference encoding) which has to be matched
 * to a certain key image to obtain the full frame.  The link to which frame has
 * to be matched with which, is found in an offset.
 * 
 * @author Emanuel Rabina
 */
public class ShpImageOffset {

	final int offset;
	final byte offsetformat;
	final int refoff;
	final byte refoffformat;

	/**
	 * Constructor, creates an offset record from the given
	 * <code>ByteBuffer</code>.
	 * 
	 * @param file <code>FilePointer</code> at an offset for the SHP file.
	 */
	ShpImageOffset(FilePointer file) {

		int off1 = file.readInt();
		offsetformat = (byte)(off1 >>> 24);
		offset = off1 & 0x00ffffff;

		int off2 = file.readInt();
		refoffformat = (byte)(off2 >>> 24);
		refoff = off2 & 0x00ffffff;
	}
}
