
// =============================================================
// Scanner's Java - Representation of a data chunk in a VQA file
// =============================================================

package redhorizon.filetypes.vqa;

import redhorizon.utilities.FilePointer;

import java.nio.ByteBuffer;
import java.nio.charset.Charset;

/**
 * Representation of a data chunk in a VQA file.  Each chunk is headed by a
 * 4-letter chunkname, then the length of that chunk in big-endian order.  The
 * data that follows is not something I wish to keep in memory, so this generic
 * chunk should do the trick.
 * 
 * @author Emanuel Rabina
 */
public class VqaChunk {

	final String chunkname;
	final int length;

	/**
	 * Constructor, takes the chunk data from the given <code>ByteBuffer</code>.
	 * 
	 * @param file <code>FilePointer</code> to the next chunk of data.
	 */
	VqaChunk(FilePointer file) {

		ByteBuffer namebytes = file.readBytes(4);
		chunkname = Charset.defaultCharset().decode(namebytes).toString();
		length    = Integer.reverseBytes(file.readInt());
	}
}
