
// ====================================================
// Scanner's Java - Representation of a VQA file header
// ====================================================

package redhorizon.filetypes.vqa;

import redhorizon.utilities.FilePointer;

import java.nio.ByteBuffer;
import java.nio.charset.Charset;

/**
 * Representation of a VQA header.  Contains information on the VQA file,
 * sounds, video data, amongst other things.
 * 
 * @author Emanuel Rabina
 */
public class VqaHeader {

	final String signature;
	final int startpos;
	final short version;
	final short flags;
	final short numframes;
	final short width;
	final short height;
	final byte blockwidth;
	final byte blockheight;
	final byte framerate;
	final byte cbparts;
	final short numcolours;
	final short maxblocks;
	final short unknown1;
	final int unknown2;
	final short frequency;
	final byte channels;
	final byte bits;
	final byte[] unknown3;

	final VqaOffset[] offsets;
	private int entry;

	/**
	 * Constructor, obtains parameters on the video from the given
	 * <code>FilePointer</code>.
	 * 
	 * @param file <code>FilePointer</code> to the VQA file's header.
	 */
	VqaHeader(FilePointer file) {

		ByteBuffer sigbytes = file.readBytes(8);
		signature   = Charset.defaultCharset().decode(sigbytes).toString();
		startpos    = Integer.reverseBytes(file.readInt());
		version     = file.readShort();
		flags       = file.readShort();
		numframes   = file.readShort();
		width       = file.readShort();
		height      = file.readShort();
		blockwidth  = file.readByte();
		blockheight = file.readByte();
		framerate   = file.readByte();
		cbparts     = file.readByte();
		numcolours  = file.readShort();
		maxblocks   = file.readShort();
		unknown1    = file.readShort();
		unknown2    = file.readInt();
		frequency   = file.readShort();
		channels    = file.readByte();
		bits        = file.readByte();
		unknown3    = file.readBytes(14).array();
		offsets     = new VqaOffset[numframes];
	}

	/**
	 * Adds a VQA chunk offset to the list of chunk offsets.
	 * 
	 * @param offset Location of the next VQA data chunk.
	 */
	void addOffset(VqaOffset offset) {

		offsets[entry++] = offset;
	}
}
