
// ===============================================
// Scanner's Java - Representation of a WSA header
// ===============================================

package redhorizon.filetypes.wsa;

import redhorizon.utilities.FilePointer;

/**
 * Representation of a WSA file's header.  Much like the SHP file, it is just
 * basic information on the contents of the file.
 * 
 * @author Emanuel Rabina
 */
public class WsaHeader {

	final short numframes;
	final short x, y;
	final short width, height;
	final int delta;
	final WsaOffset[] offsets;

	private int entry;

	/**
	 * Constructor, generates header data from the given
	 * <code>FilePointer</code>.
	 * 
	 * @param file <code>FilePointer</code> to WSA header data.
	 */
	WsaHeader(FilePointer file) {

		numframes = file.readShort();
		x         = file.readShort();
		y         = file.readShort();
		width     = file.readShort();
		height    = file.readShort();
		delta     = file.readInt();
		offsets   = new WsaOffset[numframes + 2];
	}

	/**
	 * Adds another <code>WsaOffset</code> entry to this header, in the first
	 * available position in the list of offsets.
	 * 
	 * @param newoffset The <code>ShpOffset</code> to add.
	 */
	void addOffSet(WsaOffset newoffset) {

		offsets[entry++] = newoffset;
	}
}
