
// =======================================
// Scanner's Java - 3-element float vector
// =======================================

package redhorizon.misc.geometry;

/**
 * Immutable representation of a vector in 3-dimensional space.
 * 
 * @author Emanuel Rabina
 */
public class Vector3f {

	private final float x;
	private final float y;
	private final float z;

	/**
	 * Constructor, assigns this vector initial direction values.
	 * 
	 * @param x X direction.
	 * @param y Y direction.
	 * @param z Z direction.
	 */
	public Vector3f(float x, float y, float z) {

		this.x = x;
		this.y = y;
		this.z = z;
	}

	/**
	 * Returns the X component of this vector.
	 * 
	 * @return X component.
	 */
	public float getX() {

		return x;
	}

	/**
	 * Returns the Y component of this vector.
	 * 
	 * @return Y component.
	 */
	public float getY() {

		return y;
	}

	/**
	 * Returns the Z component of this vector.
	 * 
	 * @return Z component.
	 */
	public float getZ() {

		return z;
	}

	/**
	 * Returns the XYZ values as an array.  Used primarily for OpenGL/AL array
	 * functions.
	 * 
	 * @return XYZ values, as the 0th, 1st, and 2nd values in the returned
	 * 		   3-float array.
	 */
	public float[] toArray() {

		return new float[]{ x, y, z };
	}

	/**
	 * Returns this vector represented as (x,y,z).
	 * 
	 * @return Vector3f(x,y,z).
	 */
	public String toString() {

		return "Vector3f(" + x + "," + y + "," + z + ")";
	}
}
