
// ===================================================
// Scanner's Java - Keys to Core RedHorizon.ini values
// ===================================================

package redhorizon.settings;

/**
 * Enumerated types which list the various parameters in the <code>[Core]</code>
 * section of the settings file.
 * 
 * @author Emanuel Rabina
 */
public enum CommonSettings {

	// Startup variables
	LOCALE      ("Locale"),
	RAINSTALLED ("RAInstalled"),
	TDINSTALLED ("TDInstalled");

	private final String label;

	/**
	 * Initializes each enumerated type.
	 * 
	 * @param label The way this type is represented in the settings file.
	 */
	private CommonSettings(String label) {

		this.label = label;
	}

	/**
	 * Attempts to locate the matching enumerated type label given the match
	 * parameter.
	 * 
	 * @param match The <code>String</code> representation of the type's label
	 * 				to match-up.
	 * @return The matching enumerated type.
	 */
	public static CommonSettings getMatchingType(String match) {

		for (CommonSettings types: CommonSettings.values()) {
			if (types.label.equals(match)) {
				return types;
			}
		}
		throw new EnumConstantNotPresentException(CommonSettings.class, match);
	}

	/**
	 * Returns the <code>label</code> part of the enum.
	 * 
	 * @return The label.
	 */
	public String toString() {

		return label;
	}
}
