
// ==================================================
// Scanner's Java - Blowfish encryption for MIX files
// ==================================================

package redhorizon.utilities;

import blowfishj.BlowfishECB;

import java.nio.ByteBuffer;

/**
 * Wrapper class for the Blowfish ECB Java implementation in one of the included
 * packages.  Details below:<br>
 * <br>
 * <b>BlowfishJ</b><br>
 * Version 2.20<br>
 * Written by: Markus Hahn<br>
 * Homepage: <a href="http://www.hotpixel.net/software.html" target="_new">Coder's Lagoon</a>
 * 
 * @author Emanuel Rabina
 */
public class Blowfish {

	private static BlowfishECB blowfish = new BlowfishECB();

	/**
	 * Hidden default constructor as this class is only ever meant to be used
	 * statically.
	 */
	private Blowfish() {
	}

	/**
	 * Sets the key used for encryption/decryption.
	 * 
	 * @param key  The 56 byte <code>WSkey</code> blowfish key, obtained from
	 * 			   the 80 byte key source segment in the MIX file.
	 * @param size The size of the blowfish key, normally 56 bytes.
	 */
	public static void setKey(ByteBuffer key, int size) {

		blowfish.initialize(key.array(), 0, size);
	}

	/**
	 * Decryption method for <code>ByteBuffer</code>s.
	 * 
	 * @param source The encrypted bytes.
	 * @param dest	 Destination for the decrypted bytes.
	 * @param size	 Number of bytes to decrypt (size of the source).  Normally
	 * 				 a factor of 8 as any extra that isn't will be disregarded
	 * 				 (Blowfish works on 8-byte blocks) and padded with zeros.
	 */
	public static void decrypt(ByteBuffer source, ByteBuffer dest, int size) {

		source.rewind();
		byte[] d = new byte[size];
		blowfish.decrypt(source.array(), 0, d, 0, size);
		dest.put(d).rewind();
	}

	/**
	 * Encryption method for <code>ByteBuffer</code>s.
	 * 
	 * @param source The original bytes to encrypt.
	 * @param dest	 Destination for the encrypted bytes.
	 * @param size	 Number of bytes to encrypt (size of the source).
	 */
	public static void encrypt(ByteBuffer source, ByteBuffer dest, int size) {

		source.rewind();
		byte[] d = new byte[size];
		blowfish.encrypt(source.array(), 0, d, 0, size);
		dest.put(d).rewind();
	}
}
