
// =========================================
// Scanner's Java - The Westwood Studios key
// =========================================

package redhorizon.utilities;

import java.nio.ByteBuffer;

/**
 * Interface class for the native C++ functions used to obtain the 56-byte
 * Blowfish key from the 80-byte key source found in Red Alert MIX files.
 *  
 * @author Emanuel Rabina
 */
public class WSkey {

	static {
		System.loadLibrary("WSkey");
	}

	/**
	 * Hidden default constructor, as this class is only ever meant to be used
	 * statically.
	 */
	private WSkey() {
	}

	/**
	 * Calculates the 56-byte Blowfish key from the 80-byte key source found in
	 * Red Alert's MIX files.
	 * 
	 * @param source A buffer containing the 80-byte key source.
	 * @param dest   A buffer store for the 56-byte Blowfish key.
	 */
	public static void getBlowfishKey(ByteBuffer source, ByteBuffer dest) {

		source.rewind();
		byte[] d = new byte[56];
		getBlowfishKey(source.array(), d);
		dest.put(d).rewind();

		System.out.println("Blowfish key:");
		byte[] sourcevals = source.array();
		for (int i = 0; i < 56; i++) {
			System.out.print(Integer.toHexString(sourcevals[i] & 0xff));
		}
		System.out.println();
	}

	/**
	 * This is the entry method for the public key -> private key function. A
	 * byte array of the 80-byte key source from the MIX file is given, and the
	 * 56-byte Blowfish key is calculated.
	 * 
	 * @param source A byte[] containing the 80-byte key source.
	 * @param dest   A byte[] store for the 56-byte Blowfish key.
	 */
	private native static void getBlowfishKey(byte[] source, byte[] dest);
}
